---@meta

---@class cc.TransitionRotoZoom :cc.TransitionScene
local TransitionRotoZoom = {}
cc.TransitionRotoZoom = TransitionRotoZoom

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return A autoreleased TransitionRotoZoom object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionRotoZoom:create(t, scene) end
---*
---@return self
function TransitionRotoZoom:TransitionRotoZoom() end
