---@meta

---@source UnityEngine.VRModule.dll
---@class UnityEngineInternal.XR.WSA.RemoteSpeechAccess: object
---@source UnityEngine.VRModule.dll
CS.UnityEngineInternal.XR.WSA.RemoteSpeechAccess = {}

---@source UnityEngine.VRModule.dll
---@param version UnityEngine.XR.WSA.RemoteDeviceVersion
function CS.UnityEngineInternal.XR.WSA.RemoteSpeechAccess:EnableRemoteSpeech(version) end

---@source UnityEngine.VRModule.dll
function CS.UnityEngineInternal.XR.WSA.RemoteSpeechAccess:DisableRemoteSpeech() end
