local api = {
    compile    = require 'parser.compile',
    lines      = require 'parser.lines',
    guide      = require 'parser.guide',
    luadoc     = require 'parser.luadoc'.luadoc,
}

return api
