---@meta

---@class cc.TransitionProgressRadialCCW :cc.TransitionProgress
local TransitionProgressRadialCCW = {}
cc.TransitionProgressRadialCCW = TransitionProgressRadialCCW

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return An autoreleased TransitionProgressRadialCCW object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionProgressRadialCCW:create(t, scene) end
---* js ctor
---@return self
function TransitionProgressRadialCCW:TransitionProgressRadialCCW() end
