---@meta
resty_redis = {}
function resty_redis.lrange() end
function resty_redis.new(self) end
function resty_redis.hset() end
function resty_redis.hexists() end
function resty_redis.punsubscribe() end
function resty_redis.incr() end
function resty_redis.lindex() end
function resty_redis.read_reply(self) end
function resty_redis.sismember() end
function resty_redis.set() end
function resty_redis.unsubscribe() end
function resty_redis.linsert() end
function resty_redis.zrem() end
function resty_redis.add_commands(...) end
function resty_redis.array_to_hash(self, t) end
function resty_redis.mset() end
function resty_redis.commit_pipeline(self) end
function resty_redis.zrange() end
function resty_redis.auth() end
function resty_redis.cancel_pipeline(self) end
resty_redis._VERSION = "0.27"
function resty_redis.eval() end
function resty_redis.expire() end
function resty_redis.sdiff() end
function resty_redis.sinter() end
function resty_redis.hmset(self, hashname, ...) end
function resty_redis.zrank() end
function resty_redis.psubscribe() end
function resty_redis.sunion() end
function resty_redis.sadd() end
function resty_redis.srem() end
function resty_redis.script() end
function resty_redis.lpush() end
function resty_redis.init_pipeline(self, n) end
function resty_redis.zincrby() end
function resty_redis.get_reused_times(self) end
function resty_redis.zrangebyscore() end
function resty_redis.zadd() end
function resty_redis.subscribe() end
function resty_redis.hdel() end
function resty_redis.hget() end
function resty_redis.sort() end
function resty_redis.smembers() end
function resty_redis.connect(self, ...) end
function resty_redis.hmget() end
function resty_redis.set_timeout(self, timeout) end
function resty_redis.mget() end
function resty_redis.set_keepalive(self, ...) end
function resty_redis.llen() end
function resty_redis.del() end
function resty_redis.decr() end
function resty_redis.lpop() end
function resty_redis.close() end
function resty_redis.get() end
return resty_redis
