---@meta

---@class cc.TransitionProgressRadialCW :cc.TransitionProgress
local TransitionProgressRadialCW = {}
cc.TransitionProgressRadialCW = TransitionProgressRadialCW

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return An autoreleased TransitionProgressRadialCW object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionProgressRadialCW:create(t, scene) end
---* js ctor
---@return self
function TransitionProgressRadialCW:TransitionProgressRadialCW() end
