---@meta

---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.ISoapXsd
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.ISoapXsd = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.ISoapXsd.GetXsdType() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapAnyUri: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapAnyUri = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapAnyUri.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapAnyUri
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapAnyUri:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapAnyUri.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapBase64Binary: object
---@source mscorlib.dll
---@field Value byte[]
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapBase64Binary = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapBase64Binary.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapBase64Binary
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapBase64Binary:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapBase64Binary.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDate: object
---@source mscorlib.dll
---@field Sign int
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDate = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDate.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapDate
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDate:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDate.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDateTime: object
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDateTime = {}

---@source mscorlib.dll
---@param value string
---@return DateTime
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDateTime:Parse(value) end

---@source mscorlib.dll
---@param value System.DateTime
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDateTime:ToString(value) end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDay: object
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDay = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDay.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapDay
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDay:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDay.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDuration: object
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDuration = {}

---@source mscorlib.dll
---@param value string
---@return TimeSpan
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDuration:Parse(value) end

---@source mscorlib.dll
---@param timeSpan System.TimeSpan
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapDuration:ToString(timeSpan) end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntities: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntities = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntities.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapEntities
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntities:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntities.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntity: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntity = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntity.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapEntity
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntity:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapEntity.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapHexBinary: object
---@source mscorlib.dll
---@field Value byte[]
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapHexBinary = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapHexBinary.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapHexBinary
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapHexBinary:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapHexBinary.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapId: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapId = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapId.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapId
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapId:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapId.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdrefs: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdrefs = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdrefs.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapIdrefs
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdrefs:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdrefs.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdref: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdref = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdref.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapIdref
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdref:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapIdref.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapInteger: object
---@source mscorlib.dll
---@field Value decimal
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapInteger = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapInteger.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapInteger
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapInteger:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapInteger.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapLanguage: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapLanguage = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapLanguage.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapLanguage
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapLanguage:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapLanguage.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonth: object
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonth = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonth.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapMonth
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonth:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonth.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapName: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapName = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapName.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapName
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapName:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapName.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonthDay: object
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonthDay = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonthDay.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapMonthDay
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonthDay:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapMonthDay.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNcName: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNcName = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNcName.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNcName
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNcName:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNcName.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNegativeInteger: object
---@source mscorlib.dll
---@field Value decimal
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNegativeInteger = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNegativeInteger.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNegativeInteger
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNegativeInteger:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNegativeInteger.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtoken: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtoken = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtoken.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNmtoken
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtoken:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtoken.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtokens: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtokens = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtokens.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNmtokens
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtokens:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNmtokens.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonNegativeInteger: object
---@source mscorlib.dll
---@field Value decimal
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonNegativeInteger = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonNegativeInteger.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNonNegativeInteger
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonNegativeInteger:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonNegativeInteger.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNotation: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNotation = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNotation.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNotation
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNotation:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNotation.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonPositiveInteger: object
---@source mscorlib.dll
---@field Value decimal
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonPositiveInteger = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonPositiveInteger.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNonPositiveInteger
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonPositiveInteger:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNonPositiveInteger.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapQName: object
---@source mscorlib.dll
---@field Key string
---@source mscorlib.dll
---@field Name string
---@source mscorlib.dll
---@field Namespace string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapQName = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapQName.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapQName
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapQName:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapQName.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNormalizedString: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNormalizedString = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNormalizedString.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapNormalizedString
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNormalizedString:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapNormalizedString.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapTime: object
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapTime = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapTime.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapTime
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapTime:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapTime.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapPositiveInteger: object
---@source mscorlib.dll
---@field Value decimal
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapPositiveInteger = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapPositiveInteger.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapPositiveInteger
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapPositiveInteger:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapPositiveInteger.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapToken: object
---@source mscorlib.dll
---@field Value string
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapToken = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapToken.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapToken
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapToken:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapToken.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYear: object
---@source mscorlib.dll
---@field Sign int
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYear = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYear.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapYear
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYear:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYear.ToString() end


---@source mscorlib.dll
---@class System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYearMonth: object
---@source mscorlib.dll
---@field Sign int
---@source mscorlib.dll
---@field Value System.DateTime
---@source mscorlib.dll
---@field XsdType string
---@source mscorlib.dll
CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYearMonth = {}

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYearMonth.GetXsdType() end

---@source mscorlib.dll
---@param value string
---@return SoapYearMonth
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYearMonth:Parse(value) end

---@source mscorlib.dll
---@return String
function CS.System.Runtime.Remoting.Metadata.W3cXsd2001.SoapYearMonth.ToString() end
