---@meta

---@class cc.EventTouch :cc.Event
local EventTouch = {}
cc.EventTouch = EventTouch

---*  Get event code.<br>
---* return The code of the event.
---@return int
function EventTouch:getEventCode() end
---*  Set the event code.<br>
---* param eventCode A given EventCode.
---@param eventCode int
---@return self
function EventTouch:setEventCode(eventCode) end
---* Constructor.<br>
---* js NA
---@return self
function EventTouch:EventTouch() end
