---@meta

--
--This attribute provides a way to declaratively define a Lumin privilege requirement that is automatically added to the manifest at build time.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.Lumin.UsesLuminPrivilegeAttribute: System.Attribute
---@source UnityEngine.CoreModule.dll
---@field privilege string
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.Lumin.UsesLuminPrivilegeAttribute = {}
