---@meta

---@class cc.TransitionMoveInR :cc.TransitionMoveInL
local TransitionMoveInR = {}
cc.TransitionMoveInR = TransitionMoveInR

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return A autoreleased TransitionMoveInR object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionMoveInR:create(t, scene) end
---*
---@return self
function TransitionMoveInR:TransitionMoveInR() end
