---@meta _

---@class nil
---@class never
---@class true
---@class false
---@class any: { [unknown]: any }
---@class truly: { [unknown]: any }
---@class unknown: truly | false
---@class boolean
---@class number
---@class thread
---@class table: { [unknown]: any }
---@class table<K, V>: { [K]: V }
---@class string: stringlib
---@class userdata: { [unknown]: any }
---@class lightuserdata
---@class function: fun(...): ...
