---@meta

--
--Update phase in the native player loop that waits for the operating system (OS) to flip the back buffer to the display and update the time in the engine.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.TimeUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.TimeUpdate = {}


--
--Waits for the operating system (OS) to flip the back buffer to the display and update the time in the engine.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.WaitForLastPresentationAndUpdateTime: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.WaitForLastPresentationAndUpdateTime = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.Initialization: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.Initialization = {}


---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerUpdateTime: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerUpdateTime = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateCameraMotionVectors: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateCameraMotionVectors = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorSampleTime: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorSampleTime = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.AsyncUploadTimeSlicedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.AsyncUploadTimeSlicedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.SynchronizeState: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.SynchronizeState = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.SynchronizeInputs: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.SynchronizeInputs = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.XREarlyUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.XREarlyUpdate = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.EarlyUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.EarlyUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PollPlayerConnection: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PollPlayerConnection = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProfilerStartFrame: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProfilerStartFrame = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PollHtcsPlayerConnection: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PollHtcsPlayerConnection = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.GpuTimestamp: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.GpuTimestamp = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.AnalyticsCoreStatsUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.AnalyticsCoreStatsUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UnityWebRequestUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UnityWebRequestUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateStreamingManager: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateStreamingManager = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ExecuteMainThreadJobs: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ExecuteMainThreadJobs = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProcessMouseInWindow: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProcessMouseInWindow = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ClearIntermediateRenderers: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ClearIntermediateRenderers = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ClearLines: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ClearLines = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PresentBeforeUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PresentBeforeUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ResetFrameStatsAfterPresent: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ResetFrameStatsAfterPresent = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateAsyncReadbackManager: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateAsyncReadbackManager = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateTextureStreamingManager: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateTextureStreamingManager = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdatePreloading: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdatePreloading = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.RendererNotifyInvisible: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.RendererNotifyInvisible = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerCleanupCachedData: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerCleanupCachedData = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateMainGameViewRect: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateMainGameViewRect = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateCanvasRectTransform: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateCanvasRectTransform = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateInputManager: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateInputManager = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProcessRemoteInput: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProcessRemoteInput = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.XRUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.XRUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunDelayedStartupFrame: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunDelayedStartupFrame = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateKinect: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateKinect = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DeliverIosPlatformEvents: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DeliverIosPlatformEvents = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DispatchEventQueueEvents: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DispatchEventQueueEvents = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PhysicsResetInterpolatedTransformPosition: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PhysicsResetInterpolatedTransformPosition = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.SpriteAtlasManagerUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.SpriteAtlasManagerUpdate = {}


---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.TangoUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.TangoUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ARCoreUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ARCoreUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PerformanceAnalyticsUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PerformanceAnalyticsUpdate = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.FixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.FixedUpdate = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.Update: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.Update = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PreLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PreLateUpdate = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PostLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PostLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ClearLines: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ClearLines = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorFixedSampleTime: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorFixedSampleTime = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunBehaviourUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunBehaviourUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.AudioFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.AudioFixedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunDelayedDynamicFrameRate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunDelayedDynamicFrameRate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorFixedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunDelayedTasks: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunDelayedTasks = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.LegacyFixedAnimationUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.LegacyFixedAnimationUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.XRFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.XRFixedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PhysicsFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PhysicsFixedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.Physics2DFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.Physics2DFixedUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorFixedUpdatePostPhysics: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorFixedUpdatePostPhysics = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunDelayedFixedFrameRate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunDelayedFixedFrameRate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.NewInputFixedUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.NewInputFixedUpdate = {}


--
--Update phase in the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PreUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PreUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.Physics2DLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.Physics2DLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.AIUpdatePostScript: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.AIUpdatePostScript = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorUpdateAnimationBegin: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorUpdateAnimationBegin = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.LegacyAnimationUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.LegacyAnimationUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PhysicsUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PhysicsUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorUpdateAnimationEnd: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorUpdateAnimationEnd = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorDeferredEvaluate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorDeferredEvaluate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.Physics2DUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.Physics2DUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UIElementsUpdatePanels: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UIElementsUpdatePanels = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.CheckTexFieldInput: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.CheckTexFieldInput = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateNetworkManager: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateNetworkManager = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.IMGUISendQueuedEvents: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.IMGUISendQueuedEvents = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateMasterServerInterface: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateMasterServerInterface = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.SendMouseEvents: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.SendMouseEvents = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UNetUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UNetUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.AIUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.AIUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.EndGraphicsJobsAfterScriptUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.EndGraphicsJobsAfterScriptUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.WindUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.WindUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ParticleSystemBeginUpdateAll: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ParticleSystemBeginUpdateAll = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateVideo: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateVideo = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunBehaviourLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunBehaviourLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.NewInputUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.NewInputUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ConstraintManagerUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ConstraintManagerUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerSendFrameStarted: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerSendFrameStarted = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateRectTransform: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateRectTransform = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateCanvasRectTransform: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateCanvasRectTransform = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerUpdateCanvases: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerUpdateCanvases = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateAudio: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateAudio = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateVideo: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateVideo = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ScriptRunDelayedDynamicFrameRate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ScriptRunDelayedDynamicFrameRate = {}


---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.VFXUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.VFXUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ParticleSystemEndUpdateAll: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ParticleSystemEndUpdateAll = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.EndGraphicsJobsAfterScriptLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.EndGraphicsJobsAfterScriptLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateSubstance: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateSubstance = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateCustomRenderTextures: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateCustomRenderTextures = {}


--
--Native engine system updated by the Player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.XRPostLateUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.XRPostLateUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateAllRenderers: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateAllRenderers = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateLightProbeProxyVolumes: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateLightProbeProxyVolumes = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.EnlightenRuntimeUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.EnlightenRuntimeUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateAllSkinnedMeshes: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateAllSkinnedMeshes = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProcessWebSendMessages: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProcessWebSendMessages = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.SortingGroupsUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.SortingGroupsUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateVideoTextures: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateVideoTextures = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.DirectorRenderImage: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.DirectorRenderImage = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerEmitCanvasGeometry: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerEmitCanvasGeometry = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.FinishFrameRendering: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.FinishFrameRendering = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.BatchModeUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.BatchModeUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerSendFrameComplete: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerSendFrameComplete = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateCaptureScreenshot: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateCaptureScreenshot = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PresentAfterDraw: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PresentAfterDraw = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ClearImmediateRenderers: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ClearImmediateRenderers = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.UpdateResolution: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.UpdateResolution = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.InputEndFrame: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.InputEndFrame = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.GUIClearEvents: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.GUIClearEvents = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ShaderHandleErrors: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ShaderHandleErrors = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ResetInputAxis: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ResetInputAxis = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ThreadedLoadingDebug: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ThreadedLoadingDebug = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProfilerSynchronizeStats: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProfilerSynchronizeStats = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.MemoryFrameMaintenance: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.MemoryFrameMaintenance = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ExecuteGameCenterCallbacks: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ExecuteGameCenterCallbacks = {}


--
--Native engine system updated by the Player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.XRPreEndFrame: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.XRPreEndFrame = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.ProfilerEndFrame: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.ProfilerEndFrame = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PlayerSendFramePostPresent: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PlayerSendFramePostPresent = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PhysicsSkinnedClothBeginUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PhysicsSkinnedClothBeginUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.PhysicsSkinnedClothFinishUpdate: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.PhysicsSkinnedClothFinishUpdate = {}


--
--Native engine system updated by the native player loop.
--
---@source UnityEngine.CoreModule.dll
---@class UnityEngine.PlayerLoop.TriggerEndOfFrameCallbacks: System.ValueType
---@source UnityEngine.CoreModule.dll
CS.UnityEngine.PlayerLoop.TriggerEndOfFrameCallbacks = {}
