---@meta

---@class cc.TransitionMoveInB :cc.TransitionMoveInL
local TransitionMoveInB = {}
cc.TransitionMoveInB = TransitionMoveInB

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return A autoreleased TransitionMoveInB object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionMoveInB:create(t, scene) end
---*
---@return self
function TransitionMoveInB:TransitionMoveInB() end
