---@meta

---@class cc.TransitionProgressHorizontal :cc.TransitionProgress
local TransitionProgressHorizontal = {}
cc.TransitionProgressHorizontal = TransitionProgressHorizontal

---*  Creates a transition with duration and incoming scene.<br>
---* param t Duration time, in seconds.<br>
---* param scene A given scene.<br>
---* return An autoreleased TransitionProgressHorizontal object.
---@param t float
---@param scene cc.Scene
---@return self
function TransitionProgressHorizontal:create(t, scene) end
---* js ctor
---@return self
function TransitionProgressHorizontal:TransitionProgressHorizontal() end
